@@ -27,7 +27,7 @@
 
 function v = nansum (X, varargin)
   if nargin < 1
-    usage ("v = nansum (X [, dim])");
+    print_usage;
   else
     X(isnan(X)) = 0;
     v = sum (X, varargin{:});
